@@ -14,6 +14,8 @@
 #include <inttypes.h>
 #include <assert.h>
 
+struct thread_data;
+
 #include "compiler/compiler.h"
 #include "flist.h"
 #include "fifo.h"
@@ -126,7 +128,7 @@ struct thread_stat {
 	unsigned long total_complete;
 
 	unsigned long long io_bytes[2];
-	unsigned long runtime[2];
+	unsigned long long runtime[2];
 	unsigned long total_run_time;
 
 	/*
@@ -195,6 +197,7 @@ struct thread_options {
 	char verify_pattern[MAX_PATTERN_SIZE];
 	unsigned int verify_pattern_bytes;
 	unsigned int verify_fatal;
+	unsigned int verify_dump;
 	unsigned int verify_async;
 	unsigned long long verify_backlog;
 	unsigned int verify_batch;
@@ -519,6 +522,7 @@ extern char *job_section;
 extern int fio_gtod_offload;
 extern int fio_gtod_cpu;
 extern enum fio_cs fio_clock_source;
+extern int warnings_fatal;
 
 extern struct thread_data *threads;
 
